@@ -1,12 +1,13 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Documentation/RequirePodSections.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Documentation/RequirePodSections.pm $
+#     $Date: 2009-03-07 08:51:16 -0600 (Sat, 07 Mar 2009) $
 #   $Author: clonezone $
-# $Revision: 2163 $
+# $Revision: 3227 $
 ##############################################################################
 
 package Perl::Critic::Policy::Documentation::RequirePodSections;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -14,7 +15,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :booleans :characters :severities :classification };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.098';
 
 #-----------------------------------------------------------------------------
 
@@ -27,7 +28,7 @@ Readonly::Scalar my $M_S_PBP_0_0_3       => 'module_starter_pbp_0_0_3';
 
 Readonly::Scalar my $DEFAULT_SOURCE      => $BOOK_FIRST_EDITION;
 
-my %SOURCE_TRANSLATION  = (
+Readonly::Hash   my %SOURCE_TRANSLATION  => (
     $BOOK               => $BOOK_FIRST_EDITION,
     $BOOK_FIRST_EDITION => $BOOK_FIRST_EDITION,
     $MODULE_STARTER_PBP => $M_S_PBP_0_0_3,
@@ -202,13 +203,13 @@ sub supported_parameters {
     return (
         {
             name            => 'lib_sections',
-            description     => 'The sections to require for modules (separated by qr/\s* [|] \s*/xm).',
+            description     => 'The sections to require for modules (separated by qr/\s* [|] \s*/xms).',
             default_string  => $EMPTY,
             parser          => \&_parse_lib_sections,
         },
         {
             name            => 'script_sections',
-            description     => 'The sections to require for programs (separated by qr/\s* [|] \s*/xm).',
+            description     => 'The sections to require for programs (separated by qr/\s* [|] \s*/xms).',
             default_string  => $EMPTY,
             parser          => \&_parse_script_sections,
         },
@@ -238,9 +239,9 @@ sub applies_to       { return 'PPI::Document'          }
 sub _parse_sections {
     my $config_string = shift;
 
-    my @sections = split m{ \s* [|] \s* }mx, $config_string;
+    my @sections = split m{ \s* [|] \s* }xms, $config_string;
 
-    return map { uc $_ } @sections;  #Nomalize CaSe!
+    return map { uc $_ } @sections;  # Normalize CaSe!
 }
 
 sub _parse_lib_sections {
@@ -320,20 +321,19 @@ sub violates {
                                             : @{ $self->{_lib_sections} };
 
     my $pods_ref = $doc->find('PPI::Token::Pod');
-    return if !$pods_ref;
-    my $counter  = 0;  #Might use this to enforce ordering.
+    return if not $pods_ref;
 
     # Round up the names of all the =head1 sections
     for my $pod ( @{ $pods_ref } ) {
-        for my $found ( $pod =~ m{ ^ =head1 \s+ ( .+? ) \s* $ }gmx ) {
+        for my $found ( $pod =~ m{ ^ =head1 \s+ ( .+? ) \s* $ }gxms ) {
             #Leading/trailing whitespace is already removed
-            $found_sections{ uc $found } = ++$counter;
+            $found_sections{ uc $found } = 1;
         }
     }
 
     # Compare the required sections against those we found
     for my $required ( @required_sections ) {
-        if ( ! exists $found_sections{$required} ) {
+        if ( not exists $found_sections{$required} ) {
             my $desc = qq{Missing "$required" section in POD};
             push @violations, $self->violation( $desc, $EXPL, $doc );
         }
@@ -354,15 +354,23 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Documentation::RequirePodSections
+Perl::Critic::Policy::Documentation::RequirePodSections - Organize your POD into the customary sections.
+
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
 This Policy requires your POD to contain certain C<=head1> sections.
 If the file doesn't contain any POD at all, then this Policy does not
-apply.  Tools like L<Module::Starter> make it really easy to ensure
-that every module has the same documentation framework, and they can
-save you lots of keystrokes.
+apply.  Tools like L<Module::Starter|Module::Starter> make it really
+easy to ensure that every module has the same documentation framework,
+and they can save you lots of keystrokes.
+
 
 =head1 DEFAULTS
 
@@ -370,34 +378,36 @@ Different POD sections are required, depending on whether the file is
 a library or program (which is determined by the presence or absence
 of a perl shebang line).
 
-             Default Required POD Sections
+                Default Required POD Sections
+
+    Perl Libraries                     Perl Programs
+    -----------------------------      ---------------------
+    NAME                               NAME
+    VERSION
+    SYNOPSIS                           USAGE
+    DESCRIPTION                        DESCRIPTION
+    SUBROUTINES/METHODS                REQUIRED ARGUMENTS
+                                       OPTIONS
+    DIAGNOSTICS                        DIAGNOSTICS
+                                       EXIT STATUS
+    CONFIGURATION AND ENVIRONMENT      CONFIGURATION
+    DEPENDENCIES                       DEPENDENCIES
+    INCOMPATIBILITIES                  INCOMPATIBILITIES
+    BUGS AND LIMITATIONS               BUGS AND LIMITATIONS
+    AUTHOR                             AUTHOR
+    LICENSE AND COPYRIGHT              LICENSE AND COPYRIGHT
 
-   Perl Libraries                     Perl Programs
-   ------------------------------------------------------
-   NAME                               NAME
-   VERSION
-   SYNOPSIS                           USAGE
-   DESCRIPTION                        DESCRIPTION
-   SUBROUTINES/METHODS                REQUIRED ARGUMENTS
-                                      OPTIONS
-   DIAGNOSTICS                        DIAGNOSTICS
-                                      EXIT STATUS
-   CONFIGURATION AND ENVIRONMENT      CONFIGURATION
-   DEPENDENCIES                       DEPENDENCIES
-   INCOMPATIBILITIES                  INCOMPATIBILITIES
-   BUGS AND LIMITATIONS               BUGS AND LIMITATIONS
-   AUTHOR                             AUTHOR
-   LICENSE AND COPYRIGHT              LICENSE AND COPYRIGHT
 
 =head1 CONFIGURATION
 
 The default sections above are derived from Damian Conway's I<Perl
 Best Practices> book.  Since the book has been published, Conway has
-released L<Module::Starter::PBP>, which has different names for some
-of the sections, and adds some more.  Also, the book and module use
-Australian spelling, while the authors of this module have previously
-used American spelling.  To sort this all out, there are a couple of
-options that can be used: C<source> and C<language>.
+released L<Module::Starter::PBP|Module::Starter::PBP>, which has
+different names for some of the sections, and adds some more.  Also,
+the book and module use Australian spelling, while the authors of this
+module have previously used American spelling.  To sort this all out,
+there are a couple of options that can be used: C<source> and
+C<language>.
 
 The C<source> option has two generic values, C<book> and
 C<module_starter_pbp>, and two version-specific values,
@@ -416,15 +426,15 @@ the addition of C<EXIT STATUS>.  To get precisely the sections as
 specified in the book, put the following in your F<.perlcriticrc>
 file:
 
-  [Documentation::RequirePodSections]
-  source   = book_first_edition
-  language = en_AU
+    [Documentation::RequirePodSections]
+    source   = book_first_edition
+    language = en_AU
 
 If you want to use
 
-  [Documentation::RequirePodSections]
-  source   = module_starter_pbp
-  language = en_US
+    [Documentation::RequirePodSections]
+    source   = module_starter_pbp
+    language = en_US
 
 you will need to modify your F<~/.module-starter/PBP/Module.pm>
 template because it is generated using Australian spelling.
@@ -438,9 +448,10 @@ giving values for C<script_sections> and C<lib_sections> of a string
 of pipe-delimited required POD section names.  An example of entries
 in a F<.perlcriticrc> file:
 
-  [Documentation::RequirePodSections]
-  lib_sections    = NAME | SYNOPSIS | BUGS AND LIMITATIONS | AUTHOR
-  script_sections = NAME | USAGE | OPTIONS | EXIT STATUS | AUTHOR
+    [Documentation::RequirePodSections]
+    lib_sections    = NAME | SYNOPSIS | BUGS AND LIMITATIONS | AUTHOR
+    script_sections = NAME | USAGE | OPTIONS | EXIT STATUS | AUTHOR
+
 
 =head1 LIMITATIONS
 
@@ -448,13 +459,15 @@ Currently, this Policy does not look for the required POD sections
 below the C<=head1> level.  Also, it does not require the sections to
 appear in any particular order.
 
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2006-2009 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -469,4 +482,4 @@ can be found in the LICENSE file included with this module
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
