@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Miscellanea/RequireRcsKeywords.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Miscellanea/RequireRcsKeywords.pm $
+#     $Date: 2009-03-07 08:51:16 -0600 (Sat, 07 Mar 2009) $
 #   $Author: clonezone $
-# $Revision: 2489 $
+# $Revision: 3227 $
 ##############################################################################
 
 package Perl::Critic::Policy::Miscellanea::RequireRcsKeywords;
@@ -20,7 +20,7 @@ use Perl::Critic::Utils qw{
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.098';
 
 #-----------------------------------------------------------------------------
 
@@ -64,7 +64,6 @@ sub initialize_if_enabled {
     # Set configuration, if defined.
     my @keywords = keys %{ $self->{_keywords} };
     if ( @keywords ) {
-        ## no critic ProhibitEmptyQuotes
         $self->{_keyword_sets} = [ [ @keywords ] ];
     }
 
@@ -86,24 +85,23 @@ sub violates {
             push @viols, $self->violation( $desc, $EXPL, $doc );
         }
         else {
-            my @missing_keywords = grep {
-                my $keyword_rx = qr/\$$_.*\$/xms;
-                !!none {
-                    /$keyword_rx/    ## no critic
+            my @missing_keywords =
+                grep
+                    {
+                        my $keyword_rx = qr< \$ $_ .* \$ >xms;
+                        ! ! none { m/$keyword_rx/xms } @{$nodes}
                     }
-                    @{$nodes}
-            } @{$keywordset_ref};
+                    @{$keywordset_ref};
 
             if (@missing_keywords) {
-
                 # Provisionally flag a violation. See below.
-                my $desc = 'RCS keywords '
-                    . join( ', ', map {"\$$_\$"} @missing_keywords )
-                    . ' not found';
+                my $desc =
+                    'RCS keywords '
+                        . join( ', ', map {"\$$_\$"} @missing_keywords )
+                        . ' not found';
                 push @viols, $self->violation( $desc, $EXPL, $doc );
             }
             else {
-
                 # Hey! I'm ignoring @viols for other keyword sets
                 # because this one is complete.
                 return;
@@ -116,10 +114,13 @@ sub violates {
 
 sub _wanted {
     my ( undef, $elem ) = @_;
-    return  $elem->isa('PPI::Token::Pod')
-        || $elem->isa('PPI::Token::Comment')
-        || $elem->isa('PPI::Token::Quote::Single')
-        || $elem->isa('PPI::Token::Quote::Literal');
+
+    return
+            $elem->isa('PPI::Token::Pod')
+        ||  $elem->isa('PPI::Token::Comment')
+        ||  $elem->isa('PPI::Token::Quote::Single')
+        ||  $elem->isa('PPI::Token::Quote::Literal')
+        ||  $elem->isa('PPI::Token::End');
 }
 
 1;
@@ -136,9 +137,11 @@ __END__
 
 Perl::Critic::Policy::Miscellanea::RequireRcsKeywords - Put source-control keywords in every file.
 
+
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
@@ -149,35 +152,39 @@ file helps the reader know where the file comes from, in case he or
 she needs to modify it.  This Policy scans your file for comments that
 look like this:
 
-  # $Revision: 2489 $
-  # $Source: /myproject/lib/foo.pm $
+    # $Revision: 3227 $
+    # $Source: /myproject/lib/foo.pm $
 
 A common practice is to use the C<Revision> keyword to automatically
 define the C<$VERSION> variable like this:
 
-  our ($VERSION) = '$Revision: 2489 $' =~ m{ \$Revision: \s+ (\S+) }x;
+    our ($VERSION) = '$Revision: 3227 $' =~ m{ \$Revision: \s+ (\S+) }x;
+
 
 =head1 CONFIGURATION
 
-By default, this policy only requires the C<Revision>, C<Source>, and C<Date>
-keywords.  To specify alternate keywords, specify a value for C<keywords> of a
-whitespace delimited series of keywords (without the dollar-signs).  This would
-look something like the following in a F<.perlcriticrc> file:
+By default, this policy only requires the C<Revision>, C<Source>, and
+C<Date> keywords.  To specify alternate keywords, specify a value for
+C<keywords> of a whitespace delimited series of keywords (without the
+dollar-signs).  This would look something like the following in a
+F<.perlcriticrc> file:
 
-  [Miscellanea::RequireRcsKeywords]
-  keywords = Revision Source Date Author Id
+    [Miscellanea::RequireRcsKeywords]
+    keywords = Revision Source Date Author Id
 
 See the documentation on RCS for a list of supported keywords.  Many
 source control systems are descended from RCS, so the keywords
 supported by CVS and Subversion are probably the same.
 
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2009 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
