@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Modules/ProhibitAutomaticExportation.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Modules/ProhibitAutomaticExportation.pm $
+#     $Date: 2009-03-07 08:51:16 -0600 (Sat, 07 Mar 2009) $
 #   $Author: clonezone $
-# $Revision: 2489 $
+# $Revision: 3227 $
 ##############################################################################
 
 package Perl::Critic::Policy::Modules::ProhibitAutomaticExportation;
@@ -16,12 +16,12 @@ use Perl::Critic::Utils qw{ :severities };
 use List::MoreUtils qw(any);
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.098';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Scalar my $DESC => q{Symbols are exported by default};
-Readonly::Scalar my $EXPL => q{Use '@EXPORT_OK' or '%EXPORT_TAGS' instead};  ## no critic
+Readonly::Scalar my $EXPL => q{Use '@EXPORT_OK' or '%EXPORT_TAGS' instead};  ## no critic (RequireInterpolation)
 
 #-----------------------------------------------------------------------------
 
@@ -50,20 +50,20 @@ sub _uses_exporter {
     my $includes_ref = $doc->find('PPI::Statement::Include');
     return if !$includes_ref;
     #This covers both C<use Exporter;> and C<use base 'Exporter';>
-    return scalar grep { m/ \b Exporter \b/mx }  @{ $includes_ref };
+    return scalar grep { m/ \b Exporter \b/xms }  @{ $includes_ref };
 }
 
 #------------------
 
 sub _has_exports {
     my ($doc) = @_;
-    my $wanted = sub {_our_EXPORT(@_) || _vars_EXPORT(@_) || _package_EXPORT(@_)};
+    my $wanted = sub {_our_export(@_) || _vars_export(@_) || _package_export(@_)};
     return $doc->find_first( $wanted );
 }
 
 #------------------
 
-sub _our_EXPORT {
+sub _our_export {
     my (undef, $elem) = @_;
     $elem->isa('PPI::Statement::Variable') || return 0;
     $elem->type() eq 'our' || return 0;
@@ -72,19 +72,19 @@ sub _our_EXPORT {
 
 #------------------
 
-sub _vars_EXPORT {
+sub _vars_export {
     my (undef, $elem) = @_;
     $elem->isa('PPI::Statement::Include') || return 0;
     $elem->pragma() eq 'vars' || return 0;
-    return $elem =~ m{ \@EXPORT \b }mx; #Crude, but usually works
+    return $elem =~ m{ \@EXPORT \b }xms; #Crude, but usually works
 }
 
 #------------------
 
-sub _package_EXPORT {
+sub _package_export {
     my (undef, $elem) = @_;
     $elem->isa('PPI::Token::Symbol') || return 0;
-    return $elem =~ m{ \A \@ \S+ ::EXPORT \z }mx;
+    return $elem =~ m{ \A \@ \S+ ::EXPORT \z }xms;
     #TODO: ensure that it is in _this_ package!
 }
 
@@ -100,26 +100,28 @@ __END__
 
 Perl::Critic::Policy::Modules::ProhibitAutomaticExportation - Export symbols via C<@EXPORT_OK> or C<%EXPORT_TAGS> instead of C<@EXPORT>.
 
+
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
 
-When using L<Exporter>, symbols placed in the C<@EXPORT> variable are
-automatically exported into the caller's namespace.  Although
-convenient, this practice is not polite, and may cause serious
-problems if the caller declares the same symbols.  The best practice
-is to place your symbols in C<@EXPORT_OK> or C<%EXPORT_TAGS> and let
-the caller choose exactly which symbols to export.
+When using L<Exporter|Exporter>, symbols placed in the C<@EXPORT>
+variable are automatically exported into the caller's namespace.
+Although convenient, this practice is not polite, and may cause
+serious problems if the caller declares the same symbols.  The best
+practice is to place your symbols in C<@EXPORT_OK> or C<%EXPORT_TAGS>
+and let the caller choose exactly which symbols to export.
 
-  package Foo;
+    package Foo;
 
-  use base qw(Exporter);
-  our @EXPORT      = qw(&foo &bar);                  # not ok
-  our @EXPORT_OK   = qw(&foo &bar);                  # ok
-  our %EXPORT_TAGS = ( all => [ qw(&foo &bar) ] );   # ok
+    use base qw(Exporter);
+    our @EXPORT      = qw(&foo &bar);                  # not ok
+    our @EXPORT_OK   = qw(&foo &bar);                  # ok
+    our %EXPORT_TAGS = ( all => [ qw(&foo &bar) ] );   # ok
 
 
 =head1 CONFIGURATION
@@ -131,9 +133,10 @@ This Policy is not configurable except for the standard options.
 
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2009 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
