@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/Variables/ProhibitPackageVars.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Variables/ProhibitPackageVars.pm $
+#     $Date: 2009-03-07 08:51:16 -0600 (Sat, 07 Mar 2009) $
+#   $Author: clonezone $
+# $Revision: 3227 $
 ##############################################################################
 
 package Perl::Critic::Policy::Variables::ProhibitPackageVars;
@@ -21,7 +21,7 @@ use Perl::Critic::Utils qw{
 };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.098';
 
 #-----------------------------------------------------------------------------
 
@@ -35,7 +35,7 @@ sub supported_parameters {
         {
             name            => 'packages',
             description     => 'The base set of packages to allow variables for.',
-            default_string  => 'File::Find Data::Dumper',
+            default_string  => 'Data::Dumper File::Find FindBin Log::Log4perl',
             behavior        => 'string list',
         },
         {
@@ -53,9 +53,6 @@ sub applies_to       { return qw(PPI::Token::Symbol
                                  PPI::Statement::Variable
                                  PPI::Statement::Include) }
 
-Readonly::Array our @DEFAULT_PACKAGE_EXCEPTIONS =>
-    qw( File::Find Data::Dumper );
-
 #-----------------------------------------------------------------------------
 
 sub initialize_if_enabled {
@@ -163,13 +160,13 @@ variable declarations are not package variables by default.  Thus, it
 complains you declare a variable with C<our> or C<use vars>, or if you
 make reference to variable with a fully-qualified package name.
 
-    $Some::Package::foo = 1;    #not ok
-    our $foo            = 1;    #not ok
-    use vars '$foo';            #not ok
-    $foo = 1;                   #not allowed by 'strict'
-    local $foo = 1;             #bad taste, but technically ok.
-    use vars '$FOO';            #ok, because it's ALL CAPS
-    my $foo = 1;                #ok
+    $Some::Package::foo = 1;    # not ok
+    our $foo            = 1;    # not ok
+    use vars '$foo';            # not ok
+    $foo = 1;                   # not allowed by 'strict'
+    local $foo = 1;             # bad taste, but technically ok.
+    use vars '$FOO';            # ok, because it's ALL CAPS
+    my $foo = 1;                # ok
 
 In practice though, its not really practical to prohibit all package
 variables.  Common variables like C<$VERSION> and C<@EXPORT> need to
@@ -188,7 +185,7 @@ These module can be specified from your F<.perlcriticrc> file, and the
 policy will ignore them.
 
     [Variables::ProhibitPackageVars]
-    packages = File::Find Data::Dumper
+    packages = Data::Dumper File::Find FindBin Log::Log4perl
 
 This is the default setting.  Using C<packages =>  will override these
 defaults.
@@ -216,7 +213,7 @@ Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2009 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
